/*
  mainwindow.cpp
  Copyright (C) 2010 Tomohiro Masubuchi <bucchi@e-ml.jp>

  This file is part of radiko-player.

  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; If not, see <http://www.gnu.org/licenses/>.
*/

//#define DEBUG

#include "mainwindow.h"
#include "radiko.h"

#include <qwidget.h>
#include <stdio.h>
#include <stdlib.h>
#include "version.h"
#include "process.h"

#include <qlayout.h>
#include <qhbox.h>
#include <qcombobox.h>
#include <qpushbutton.h>
#include <qtextstream.h>

#include <qdir.h>

#ifdef QWS
#define CHLIST_FILE "/home/zaurus/Settings/radiko-chlist.txt"
#define CHLIST_DEF_FILE "/opt/QtPalmtop/share/radiko/chlist-def.txt"
#else
#define CHLIST_FILE "chlist.txt"
#define CHLIST_DEF_FILE "chlist-def.txt"
#endif

MainWindow::MainWindow( QWidget *parent, const char *name, WFlags fl) :
	QWidget(parent, name, fl)
{
//	conf = new QGConf(this, "config");

#ifndef QWS
	resize(640,640);
#endif
	setCaption(QString::fromUtf8("radiko player - ") + RADIKO_VER);

	QVBoxLayout *vbox = new QVBoxLayout(this);
	QHBox *hbox = new QHBox(this);
	QWidget *l_dummy = new QWidget(hbox);
	hbox->setStretchFactor(l_dummy, 100);
	channel = new QComboBox(hbox);
	button = new QPushButton("Play", hbox);

	QWidget *r_dummy = new QWidget(hbox);
	hbox->setStretchFactor(r_dummy, 100);
	vbox->addWidget(hbox);

	connect(button, SIGNAL(clicked()),
			this, SLOT(toggle_playbutton()));
	connect(&proc, SIGNAL(started()),
			this, SLOT(process_start()));
	connect(&proc, SIGNAL(exited()),
			this, SLOT(process_stop()));

#if 0
	struct channel_info *chinfo;
	chinfo = new struct channel_info;
	chinfo->name = QString::fromUtf8("NHK第一");
	chinfo->cmd = "./nhk1.sh";
	ch.append(chinfo);

	chinfo = new struct channel_info;
	chinfo->name = QString::fromUtf8("NHK第二");
	chinfo->cmd = "./nhk2.sh";
	ch.append(chinfo);

	chinfo = new struct channel_info;
	chinfo->name = QString::fromUtf8("NHK-FM");
	chinfo->cmd = "./nhk-fm.sh";
	ch.append(chinfo);
#endif

	if (!ch.load(CHLIST_FILE)) {
	    system("cp " CHLIST_DEF_FILE " " CHLIST_FILE);
	    if (!ch.load(CHLIST_FILE))
		return;
	}

	updateChannelList();
}

MainWindow::~MainWindow()
{
    proc.stop();
}

void MainWindow::updateChannelList()
{
    struct channel_info *chinfo;
    channel->clear();

    for (chinfo = ch.first(); chinfo; chinfo = ch.next()) {
	channel->insertItem(chinfo->name);
    }
}

void MainWindow::toggle_playbutton()
{
	bool play = (button->text() == "Play");
	printf("button:%d\n", play);
	printf("index:%d\n", channel->currentItem());
	struct channel_info *chinfo;
	chinfo = ch.at(channel->currentItem());
	printf("name:%s cmd:%s\n",
	       (const char *)chinfo->name.utf8(),
	       (const char *)chinfo->cmd.utf8());

	if (play) {
		proc.setCommand(chinfo->cmd);
		proc.start();
		button->setText("Stop");
	} else {
		proc.stop();
	}
}

void MainWindow::process_start()
{
    printf("start!!\n");
    button->setOn(false);
    button->setText("Stop");
}

void MainWindow::process_stop()
{
    printf("stop!!\n");
    button->setOn(true);
    button->setText("Play");
}
